<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="ms_MY" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Perihal</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Mula torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Langkau semakan cincangan</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Cipta subfolder</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Mod Pengurusan Torrent:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Semua</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Tiada Kategori</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Tambah kategori...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Buang kategori</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Buang kategori yang tidak digunakan</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Sambung semula torrent</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Jeda torrent</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Padam torrent</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Kategori Baharu</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Sunting Kategori...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Keluar qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Hanya satu pautan per baris</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Had kadar muat naik sejagat mesti lebih besar dari 0 atau dilumpuhkan.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Had kadar muat turun sejagat mesti lebih besar dari 0 atau dilumpuhkan.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Had kadar muat naik alternatif mesti lebih besar dari 0 atau dilumpuhkan.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Had kadar muat turun alternatif mesti lebih besar dari 0 atau dilumpuhkan.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Muat turun aktif maksimum mesti lebih besar dari -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Muat naik aktif maksimum mesti lebih besar dari -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Torrent aktif maksimum mesti lebih besar dari -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Bilangan had sambungan maksimum mesti lebih besar dari 0 atau dilumpuhkan.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Bilangan sambungan had per torrent maksimum mesti lebih besar dari 0 atau dilumpuhkan.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Bilangan slot muat naik per had torrent maksimum mesti lebih besar dari 0 atau dilumpuhkan.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Tidak boleh simpan keutamaan program, qBittorrent berkemungkinan tidak boleh dicapai.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent di Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tidak diketahui</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Had nisbah kongsi mesti diantara 0 hingga 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Had masa penyemaian mesti diantara 0 hingga 525600 minit.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Port yang digunakan untuk sambungan masuk mestilah diantara 1 hingga 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Port yang digunakan untuk UI Sesawang mestilah diantara 1 hingga 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Tidak boleh daftar masuk, qBittorrent berkemungkinan tidak boleh dicapai.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Nama Pengguna atau Kata Laluan tidak sah.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kata Laluan</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Daftar Masuk</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Pengarang asal</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Laksana</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tambah</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Muat Naik Torrent</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Simpan fail ke lokasi:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Kuki:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Taip folder di sini</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Lagi maklumat</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Maklumat berkenaan sijil</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Tetapkan lokasi</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Had kadar muat naik</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Had kadar muat turun</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Nama semula torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Lain-lain...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Isnin</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Selasa</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Rabu</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Khamis</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Jumaat</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sabtu</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Ahad</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Daftar keluar</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Muat turun Torrent dari URL atau pautan Magnet mereka</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Muat naik torrent setempat</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Anda pasti mahu memadam torrent terpilih dari senarai pemindahan?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Klien qBittorrent tidak dapat dicapai</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Bilangan sejagat had slot muat naik mesti lebih besar dari 0 atau lumpuhkan.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Nama kategori tidak sah:\nJangan guna apa jua aksara khas  dalam nama kategori.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Tidak boleh mencipta kategori</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Ambang kadar muat naik mesti lebih besar dari 0</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Sunting</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Ruang bebas: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Pemasa ketidakaktifan torrent mesti lebih besar dari 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Pengurusan Penjimatan</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Ambang kadar muat turun mesti lebih besar dari 0</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent telah dimatikan</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Sunting</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Alat</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fail</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Pilihan...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Sambung Semula</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Keutamaan Minimum</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Keutamaan Tertinggi</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Rendahkan Keutamaan</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Tingkatkan Keutamaan</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Palang Alat Atas</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Palang Status</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Kelajuan dalam Palang Tajuk</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Beri Derma!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Sambung Semula Semua</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Perihal</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Jeda</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Jeda Semua</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Tambah Fail Torrent...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentasi</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Tambah Pautan Torrent...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ya</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Tidak</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Had Kelajuan Muat Naik Sejagat</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Had Kelajuan Muat Turun Sejagat</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Anda pasti mahu keluar dari qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[T: %1, N: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Had kelajuan alternatif</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Enjin Gelintar</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Tapis senarai torrent...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Pemindahan</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Muat Turun</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Sambungan</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Kelajuan</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>UI Sesawang</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Bahasa</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Bahasa Antaramuka Pengguna:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Pemberitahuan emel seusai muat turun lengkap</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Jalankan program luar bila torrent selesai</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Penapisan IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Jadualkan penggunaan had kadar alternatif</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Pembarisan Gilir Torrent</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Semai torrent sehingga nisbah mereka tercapai</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Tambah penjejak ini secara automatik ke muat turun baharu:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Antaramuka Pengguna Sesawang (Kawalan jauh)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>Alamat IP:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Domain pelayan:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Guna HTTPS selain dari HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Lepasi pengesahihan untuk klien pada localhost</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Lepasi pengesahihan untuk klien dalam subnet IP tersenarai putih</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Kemaskini nama domain dinamik saya</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Kekalkan torrent tidak selesai dalam:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Salin fail .torrent ke:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Salin fail .torrent bagi muat turun yang selesai ke:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Pra-peruntuk ruang cakera untuk semua fail</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Tambah sambungan .!qB pada fail tidak lengkap</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Tambah torrent secara automatik dari:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Pelayan SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Pelayan ini memerlukan satu sambungan selamat (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Pengesahihan</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nama pengguna:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Kata laluan:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Protokol dibenarkan:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP dan μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Port Dengar</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Port yang digunakan untuk sambungan masuk:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Guna pemajuan port UPnP / NAT-PMP daripada penghala saya</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Guna port berlainan bagi setiap permulaan</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Had Sambungan</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Bilangan sambungan per torrent maksimum:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Bilangan sambungan maksimum sejagat:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Bilangan slot muat naik per torrent maksimum:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Bilangan maksimum sejagat bagi slot muat naik:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Pelayan Proksi</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Jenis:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Tiada)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Hos:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Guna proksi untuk sambungan rakan</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Lumpuhkan sambungan yang tidak disokong oleh proksi</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Guna proksi hanya untuk torrent</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Tapis laluan (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Alamat IP dilarang secara manual...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Laksana kepada penjejak</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Had Kadar Sejagat</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Muat naik:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Muat Turun:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Had Kadar Alternatif</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Daripada:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Kepada:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Bila:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Setiap hari</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Hari biasa</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Hujung minggu</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Tetapan Had Kadar</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Laksana had kadar untuk overhed angkutan</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Laksana had kadar ke protokol µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Kerahsiaan</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Benarkan DHT (rangkaian tak sepusat) untuk dapatkan lagi rakan</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Benarkan Pertukaran Rakan (PeX) untuk dapatkan lagi rakan</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Benarkan Penemuan Rakan Setempat untuk cari lagi rakan</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Mod penyulitan:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Utamakan penyulitan</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Perlu penyulitan</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Lumpuhkan penyulitan</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Benarkan mod awanama</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Muat turun aktif maksimum:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Muat naik aktif maksimum:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Torrent aktif maksimum:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Jangan kira torrent lembab dalam had ini</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Pembatasan Nisbah Kongsi</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Semai torrent sehingga nisbah mereka tercapai</translation>
    </message>
    <message>
        <source>then</source>
        <translation>maka</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Jedakannya</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Buangkannya</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Guna UPnP / NAT-PMP untuk majukan port daripada penghala saya</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Sijil:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Kunci:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Daftar</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Nama domain:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Parameter disokong (peka kata):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Nama torrent</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategori</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation>%G: Tags (diasing dengan tanda koma)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Laluan kandungan (sama dengan laluan root untuk torrent berbilang-fail)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Laluan root (laluan subdirektori torrent pertama)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Laluan simpan</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Bilangan fail</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Saiz torrent (bait)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Penjejak semasa</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Cincangan maklumat</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Petua: Parameter dalam kurungan dengan tanda petikan untuk menghindari teks dipotong pada ruang putih (contohnya., "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Nama pengguna UI Sesawang mestilah sekurang-kurangnya 3 aksara panjangnya.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Kata laluan UI Sesawang mestilah sekurang-kurangnya 6 aksara panjangnya.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minit</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Benarkan perlindungan godaman klik</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Benarkan perlindungan Pemalsuan Pintaan Silang-Laman (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Padam fail .torrent selepas itu</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Ambang kadar muat turun:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Ambang kadar muat naik:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Ubah kata laluan semasa</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatik</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Guna UI Sesawang alternatif</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Laluan Simpan Lalai:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Lokasi fail UI Sesawang alternatif tidak boleh kosong.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Jangan mulakan muat turun secara automatik</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Tukar torrent ke Mod Manual</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Bila Kategori Torrent berubah:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Tempat semula torrent yang dipengaruhi</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Laksana had kadar kepada rakan dalam LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 bermaksud tanpa had</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Tempat semula torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Bila Laluan Simpan Lalai berubah:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Benarkan pengesahan pengepala hos</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Keselamatan</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Bila Laluan Simpan Kategori berubah:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Cipta subfolder untuk torrent dengan fail berbilang</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>saat</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Tukar torrent yang dipengaruhi ke Mod Manual</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Lokasi fail:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Pemasa ketidakaktifan torrent:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Mod Pengurusan Torrent Lalai:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Bila menambah sebuah torrent</translation>
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Bendera</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Sambungan</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Klien</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Kemajuan</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Kelajuan Turun</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Kelajuan Naik</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Dimuat Turun</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Dimuat Naik</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Berkaitan</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Fail</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Negara</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Biasa</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Tinggi</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maksimum</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Am</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Penjejak</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Rakan</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Sumber HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Kandungan</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Dimuat Turun:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Pemindahan</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Masa Aktif:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>ETA:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Dimuat Naik:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Semaian:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Kelajuan Muat Turun:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Kelajuan Muat Naik:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Rakan:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Had Muat Turun:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Had Muat Naik:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Tersia:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Sambungan:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Maklumat</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Ulasan:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Nisbah Kongsi:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Diumum Semula Dalam Tempoh:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Terakhir Dilihat Selesai:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Jumlah Saiz:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Cebisan:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Dicipta Oleh:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Ditambah Pada:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Selesai Pada:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Dicipta Pada:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Cincangan Torrent:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Laluan Simpan:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Tidak sesekali</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (mempunyai %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 sesi ini)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 maks)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 jumlah)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 pur.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Had muat turun:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Had muat naik:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Folder Dipantau</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Batalkan Lokasi Simpan</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Folder dipantau</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Lokasi simpan lalai</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Statistik pengguna</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Statistik cache</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Hit cache baca:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Masa purata dalam baris gilir:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Rakan bersambung:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Nisbah kongsi sepanjang-masa:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Muat turun sepanjang-masa:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Sisa sesi:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Muat naik sepanjang-masa</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Jumlah saiz penimbal:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Statistik prestasi</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Kerja I/O dibaris gilir:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Beban lampau cache tulis:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Beban lampau cache tulis:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Jumlah saiz dibaris gilir:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 nod</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Semua (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Memuat Turun (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Menyemai (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Selesai (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Disambung Semula (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Dijeda (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktif (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Tidak Aktif (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Dengan Ralat (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Semua (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Memuat Turun (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Menyemai (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Selesai (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Dijeda (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Disambung Semula (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktif (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Tidak Aktif (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Dengan Ralat (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Saiz</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Kemajuan</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Keutamaan Muat Turun</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Berbaki</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Ketersediaan</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Saiz</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Selesai</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Status</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Semai</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Rakan</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Kelajuan Turun</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Kelajuan Naik</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Nisbah</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>ETA</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Tag:</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Ditambah Pada</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Selesai Pada</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Penjejak</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Had Turun</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Had Naik</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Dimuat Turun</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Dimuat Naik</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Sesi Muat Turun</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Sesi Muat Naik</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Berbaki</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Masa Aktif</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Laluan simpan</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Selesai</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Had Nisbah</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Terakhir Dilihat Selesai</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Aktiviti Terakhir</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Jumlah Saiz</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Rakan</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mesej</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Dimuat turun</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL penjejak:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Mengemaskini...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Berusaha</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Dilumpuhkan</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Belum dihubungi lagi</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>T/A</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Semai</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Tidak berfungsi</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Salin URL penjejak</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Tambah satu penjejak baharu...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Sunting URL penjejak...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Penyuntingan penjejak</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Sedut</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Buang penjejak</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Dialog penambahan penjejak</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Senarai penjejak yang ditambahkan (satu per baris):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 yang lalu</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Memperuntukkan</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Dijeda</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Selesai</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Beralih</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[P] Menyemai</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Menyemai</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Dibaris gilir</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Dengan ralat</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[P] Memuat turun</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Memuat turun data meta</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Memeriksa</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Fail Hilang</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Dibaris gilir untuk penyemakan</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Memuat turun</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Menyemak data sambung semula</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Tertegun</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategori</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Pembatasan Kelajuan Muat Turun Torrent</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Pembatasan Kelajuan Muat Naik Torrent</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nama semula</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Sambung Semula</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Paksa Sambung Semula</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Jeda</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Had nisbah kongsi...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Had kadar muat naik...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Had kadar muat turun...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Alih ke atas</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Alih ke bawah</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Alih ke teratas</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Alih ke terbawah</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Tetapkan lokasi...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Salin nama</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Salin cincangan</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Muat turn cebisan pertama dan terakhir dahulu</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Pengurusan Torrent Automatik</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Baharu...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Tetap Semula</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Keutamaan</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Paksa semak semula</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Salin pautan magnet</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Mod penyemaian super</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Nama semula...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Muat turun dalam tertib berjujukan</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Paksa semak semula</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Kategori Baharu</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Lokasi</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nama baharu</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Tetapkan lokasi</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Paksa umum semula</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Sunting Kategori</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Laluan simpan</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Pembatasan Nisbah Muat Naik/Muat Turun Torrent</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Guna had kongsi sejagat</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Tetapkan had tanpa kongsi</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Tetapkan had kongsi sehingga</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>nisbah</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minit</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Klien BiTorrent lanjutan yang diaturcara dalam C++, berasaskan pada kit alat Qt dan libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Laman Rumah:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forum:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Penjejak Pepijat:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Pengesahan pemadaman</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Juga padam fail pada cakera keras</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Pengesahan pemadaman - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Muat turun dari URL</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Muat turun</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Tambah Pautan Torrent</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1j %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1h %2j</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Tidak diketahui</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Laluan simpan kosong</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Laluan pemalam:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL atau direktori setempat</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Pasang pemalam</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Semaian:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Semua pemalam</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Saiz:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Henti</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Gelintar pemalam...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Semua kategori</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Gelintar dalam:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Salin URL halaman keterangan</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Pergi ke halaman keterangan</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Keputusan (menunjukkan</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Muat turun</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Penapis</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Nama torrent sahaja</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Hanya dibenarkan</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>luar dari</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Di mana sahaja</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Nyahpasang</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Pasang pemalam baharu</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Anda boleh dapatkan pemalam enjin gelintar baharu di sini:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Pemalam gelintar dipasang:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Dibenarkan</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Amaran: Pastikan menuruti undang-undang hakcipta negara anda ketika memuat turun torrent dari mana-mana enjin gelintar.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Periksa kemaskini</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Pemalam gelintar</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Saiz</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Penyedut</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Enjin gelintar</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Penyemai</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Dibenarkan</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versi</translation>
    </message>
</context>
</TS>